@@ -4,14 +4,7 @@ http://asciimatics.readthedocs.io/en/latest/animation.html
 """
 
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-from builtins import object
-
-
-class Scene(object):
+class Scene():
     """
     Class to store the details of a single scene to be displayed.  This is
     made up of a set of :py:obj:`.Effect` objects.  See the documentation for
@@ -32,7 +25,7 @@ class Scene(object):
             self.add_effect(effect, reset=False)
         self._duration = duration
         if duration == 0:
-            self._duration = max([x.stop_frame for x in effects])
+            self._duration = max(x.stop_frame for x in effects)
         self._clear = clear
         self._name = name
 
